==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/AsyncCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescription } from "./AsyncCompletedEventArgsDescription";
/**
 * @hidden
 */
export let AsyncCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AsyncCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AsyncCompletedEventArgsDescriptionMetadata.a == null) {
                AsyncCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AsyncCompletedEventArgsDescriptionMetadata.c(AsyncCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.k(AsyncCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(AsyncCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            AsyncCompletedEventArgsDescriptionMetadata.b(a);
            a.ad("AsyncCompletedEventArgs", () => new AsyncCompletedEventArgsDescription());
            a.ac("AsyncCompletedEventArgs", AsyncCompletedEventArgsDescriptionMetadata.a);
        }
    }
    AsyncCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AsyncCompletedEventArgsDescriptionMetadata, 'AsyncCompletedEventArgsDescriptionMetadata');
    AsyncCompletedEventArgsDescriptionMetadata.a = null;
    return AsyncCompletedEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/AsyncCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AsyncCompletedEventArgsDescription } from "./AsyncCompletedEventArgsDescription";
/**
 * @hidden
 */
export let AsyncCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AsyncCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AsyncCompletedEventArgsDescriptionMetadata.a == null) {
                AsyncCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AsyncCompletedEventArgsDescriptionMetadata.c(AsyncCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.k(AsyncCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AsyncCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            AsyncCompletedEventArgsDescriptionMetadata.b(a);
            a.ae("AsyncCompletedEventArgs", () => new AsyncCompletedEventArgsDescription());
            a.ad("AsyncCompletedEventArgs", AsyncCompletedEventArgsDescriptionMetadata.a);
        }
    }
    AsyncCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AsyncCompletedEventArgsDescriptionMetadata, 'AsyncCompletedEventArgsDescriptionMetadata');
    AsyncCompletedEventArgsDescriptionMetadata.a = null;
    return AsyncCompletedEventArgsDescriptionMetadata;
})();
